* [PATCH] [media] gp8psk-fe: add missing MODULE_foo() macros
@ 2016-11-14 13:14 Mauro Carvalho Chehab
2016-11-14 13:37 ` Paul Bolle
0 siblings, 1 reply; 2+ messages in thread
From: Mauro Carvalho Chehab @ 2016-11-14 13:14 UTC (permalink / raw)
To: Linus Torvalds; +Cc: Stephen Rothwell, linux-next, linux-kernel
This file was converted to a separate module at commit
7a0786c19d65 ("gp8psk: Fix DVB frontend attach"), because
the DVB attach routines require it to work. However,
I forgot to copy the MODULE_foo() macros from the original
module, causing this warning:
WARNING: modpost: missing MODULE_LICENSE() in drivers/media/dvb-frontends/gp8psk-fe.o
Reported-by: Stephen Rothwell <sfr@canb.auug.org.au>
Fixes: 7a0786c19d65 ("gp8psk: Fix DVB frontend attach")
Signed-off-by: Mauro Carvalho Chehab <mchehab@s-opensource.com>
diff --git a/drivers/media/dvb-frontends/gp8psk-fe.c b/drivers/media/dvb-frontends/gp8psk-fe.c
index be19afeed7a9..93f59bfea092 100644
--- a/drivers/media/dvb-frontends/gp8psk-fe.c
+++ b/drivers/media/dvb-frontends/gp8psk-fe.c
@@ -1,5 +1,5 @@
/* DVB USB compliant Linux driver for the
* - GENPIX 8pks/qpsk/DCII USB2.0 DVB-S module
*
* Copyright (C) 2006,2007 Alan Nisota (alannisota@gmail.com)
* Copyright (C) 2006,2007 Genpix Electronics (genpix@genpix-electronics.com)
@@ -8,11 +8,9 @@
*
* This module is based off the vp7045 and vp702x modules
*
- * This program is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License as published by the Free
- * Software Foundation, version 2.
- *
- * see Documentation/dvb/README.dvb-usb for more information
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the Free
+ * Software Foundation, version 2.
*/
#define pr_fmt(fmt) KBUILD_MODNAME ": " fmt
@@ -395,3 +393,8 @@ static struct dvb_frontend_ops gp8psk_fe_ops = {
.dishnetwork_send_legacy_command = gp8psk_fe_send_legacy_dish_cmd,
.enable_high_lnb_voltage = gp8psk_fe_enable_high_lnb_voltage
};
+
+MODULE_AUTHOR("Alan Nisota <alannisota@gamil.com>");
+MODULE_DESCRIPTION("Frontend Driver for Genpix DVB-S");
+MODULE_VERSION("1.1");
+MODULE_LICENSE("GPL");
Thanks,
Mauro
^ permalink raw reply related [flat|nested] 2+ messages in thread* Re: [PATCH] [media] gp8psk-fe: add missing MODULE_foo() macros
2016-11-14 13:14 [PATCH] [media] gp8psk-fe: add missing MODULE_foo() macros Mauro Carvalho Chehab
@ 2016-11-14 13:37 ` Paul Bolle
0 siblings, 0 replies; 2+ messages in thread
From: Paul Bolle @ 2016-11-14 13:37 UTC (permalink / raw)
To: Mauro Carvalho Chehab
Cc: Linus Torvalds, Stephen Rothwell, linux-next, linux-kernel
On Mon, 2016-11-14 at 11:14 -0200, Mauro Carvalho Chehab wrote:
> --- a/drivers/media/dvb-frontends/gp8psk-fe.c
> +++ b/drivers/media/dvb-frontends/gp8psk-fe.c
> + * This program is free software; you can redistribute it and/or modify it
> + * under the terms of the GNU General Public License as published by the Free
> + * Software Foundation, version 2.
> +MODULE_LICENSE("GPL");
Nit: according to the comments in include/linux/module.h the "ident" that
matches the license described at the top of this file is "GPL v2".
Paul Bolle
^ permalink raw reply [flat|nested] 2+ messages in thread
end of thread, other threads:[~2016-11-14 13:37 UTC | newest]
Thread overview: 2+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2016-11-14 13:14 [PATCH] [media] gp8psk-fe: add missing MODULE_foo() macros Mauro Carvalho Chehab
2016-11-14 13:37 ` Paul Bolle
This is a public inbox, see mirroring instructions
@@ -1,5 +1,5 @@
-/* DVB USB compliant Linux driver for the
- * - GENPIX 8pks/qpsk/DCII USB2.0 DVB-S module
+/*
+ * Frontend driver for the GENPIX 8pks/qpsk/DCII USB2.0 DVB-S module
*
* Copyright (C) 2006,2007 Alan Nisota (alannisota@gmail.com)
for how to clone and mirror all data and code used for this inbox